@@ -1,4 +1,5 @@
 define(['appStorage', 'browser'], function (appStorage, browser) {
+    'use strict';
 
     function getDeviceProfile() {
 
@@ -148,19 +149,18 @@ define(['appStorage', 'browser'], function (appStorage, browser) {
             features.push('fullscreen');
         }
 
-        if (browser.chrome || (browser.safari && !browser.mobile)) {
+        if (browser.chrome || (browser.edge && !browser.slow)) {
             features.push('imageanalysis');
         }
 
         return features;
     }();
 
-
     var appInfo;
     var version = window.dashboardVersion || '3.0';
 
     return {
-        dvrFeatureCode: Dashboard.isConnectMode() ? 'dvr' : 'dvrl',
+        dvrFeatureCode: 'dvr',
         getWindowState: function () {
             return document.windowState || 'Normal';
         },
@@ -189,6 +189,7 @@ define(['appStorage', 'browser'], function (appStorage, browser) {
             var features = [];
 
             features.push('playback');
+            features.push('livetv');
 
             return features;
         },
