@@ -1,4 +1,5 @@
-﻿define(['dialogHelper', 'emby-checkbox', 'emby-button', 'paper-icon-button-light'], function (dialogHelper) {
+﻿define(['dialogHelper', 'imageLoader', 'emby-checkbox', 'emby-button', 'paper-icon-button-light', 'css!css/metadataeditor.css'], function (dialogHelper, imageLoader) {
+    'use strict';
 
     var currentItemId;
     var currentItemType;
@@ -71,7 +72,7 @@
 
         var availableImagesList = page.querySelector('.availableImagesList');
         availableImagesList.innerHTML = html;
-        ImageLoader.lazyChildren(availableImagesList);
+        imageLoader.lazyChildren(availableImagesList);
 
         var btnNextPage = page.querySelector('.btnNextPage');
         var btnPreviousPage = page.querySelector('.btnPreviousPage');
@@ -276,7 +277,7 @@
             reloadBrowsableImages(page);
         });
 
-        page.addEventListener('click', function(e) {
+        page.addEventListener('click', function (e) {
 
             var btnDownloadRemoteImage = parentWithClass(e.target, 'btnDownloadRemoteImage');
             if (btnDownloadRemoteImage) {
@@ -308,7 +309,6 @@
 
             dlg.classList.add('ui-body-' + theme);
             dlg.classList.add('background-theme-' + theme);
-            dlg.classList.add('popupEditor');
 
             var html = '';
             html += '<h2 class="dialogHeader">';
@@ -321,7 +321,6 @@
             html += '</div>';
 
             dlg.innerHTML = html;
-            document.body.appendChild(dlg);
 
             // Has to be assigned a z-index after the call to .open() 
             dlg.addEventListener('close', onDialogClosed);
