@@ -1,4 +1,5 @@
 ﻿define(['libraryBrowser', 'dom', 'components/categorysyncbuttons', 'cardBuilder', 'apphost', 'scrollStyles', 'emby-itemscontainer', 'emby-tabs', 'emby-button'], function (libraryBrowser, dom, categorysyncbuttons, cardBuilder, appHost) {
+    'use strict';
 
     return function (view, params) {
 
@@ -34,7 +35,6 @@
                 }
 
                 var container = view.querySelector('#nextUpItems');
-
                 var supportsImageAnalysis = appHost.supports('imageanalysis');
 
                 cardBuilder.buildCards(result.Items, {
@@ -98,7 +98,8 @@
 
                 var container = view.querySelector('#resumableItems');
 
-                var cardLayout = appHost.preferVisualCards;
+                var supportsImageAnalysis = appHost.supports('imageanalysis');
+                var cardLayout = supportsImageAnalysis;
 
                 cardBuilder.buildCards(result.Items, {
                     itemsContainer: container,
@@ -111,7 +112,8 @@
                     centerText: !cardLayout,
                     overlayPlayButton: true,
                     allowBottomPadding: allowBottomPadding,
-                    cardLayout: cardLayout
+                    cardLayout: cardLayout,
+                    vibrant: supportsImageAnalysis
                 });
             });
         }
@@ -158,14 +160,14 @@
                     depends.push('scripts/tvshows');
                     break;
                 case 4:
-                    depends.push('scripts/episodes');
-                    break;
-                case 5:
                     depends.push('scripts/tvgenres');
                     break;
-                case 6:
+                case 5:
                     depends.push('scripts/tvstudios');
                     break;
+                case 6:
+                    depends.push('scripts/episodes');
+                    break;
                 default:
                     break;
             }
